.. yellowbrick documentation master file, created by
   sphinx-quickstart on Tue Jul  5 19:45:43 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to yellowbrick's documentation!
=======================================

**Yellowbrick is a suite of visual analysis and diagnostic tools to facilitate feature selection, model selection, and parameter tuning for machine learning.**

Tools for feature analysis and selection
------------------------------------------

- boxplots (box-and-whisker plots)
- violinplots
- histograms
- scatter plot matrices (sploms)
- radial visualizations (radviz)
- parallel coordinates
- jointplots
- diagonal correlation matrix


Tools for model evaluation
----------------------------

Classification
^^^^^^^^^^^^^^^

- ROC curves
- classification heatmaps

Regression
^^^^^^^^^^^^

- prediction error plots
- residual plots


Tools for parameter tuning
----------------------------

- validation curves
- gridsearch heatmap






Contents:
==========

.. toctree::
   :maxdepth: 2

   setup
   api/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

